about summary refs log tree commit diff
diff options
context:
space:
mode:
authorBrian Anderson <banderson@mozilla.com>2011-08-18 15:00:12 -0700
committerBrian Anderson <banderson@mozilla.com>2011-08-18 15:01:49 -0700
commitf5ce3bf15d5f636bb73b7aae671b3a9e9681f38e (patch)
treedc32b6ef3e3413458ef34ebc85b322cca28f0438
parent223f6017c796898722c0fcb78fabf973120e1344 (diff)
downloadrust-f5ce3bf15d5f636bb73b7aae671b3a9e9681f38e.tar.gz
rust-f5ce3bf15d5f636bb73b7aae671b3a9e9681f38e.zip
More misc ivec->vec renaming
-rw-r--r--src/comp/middle/ty.rs4
-rw-r--r--src/comp/syntax/ext/simplext.rs2
-rw-r--r--src/comp/syntax/untyped_ast.rs4
-rw-r--r--src/test/compile-fail/bad-module.rs4
-rw-r--r--src/test/pretty/vec-type.pp (renamed from src/test/pretty/ivec-type.pp)2
-rw-r--r--src/test/pretty/vec-type.rs (renamed from src/test/pretty/ivec-type.rs)2
6 files changed, 9 insertions, 9 deletions
diff --git a/src/comp/middle/ty.rs b/src/comp/middle/ty.rs
index 8352d5f9e28..cf46e8b2a0f 100644
--- a/src/comp/middle/ty.rs
+++ b/src/comp/middle/ty.rs
@@ -1348,7 +1348,7 @@ fn type_param(cx: &ctxt, ty: &t) -> option::t<uint> {
     ret none;
 }
 
-// Returns an ivec of all the type variables
+// Returns a vec of all the type variables
 // occurring in t. It may contain duplicates.
 fn vars_in_type(cx:&ctxt, ty: &t) -> [int] {
     fn collect_var(cx:&ctxt, vars: &@mutable [int], ty: t) {
@@ -1362,7 +1362,7 @@ fn vars_in_type(cx:&ctxt, ty: &t) -> [int] {
     let rslt: @mutable [int] = @mutable (~[]);
     walk_ty(cx, bind collect_var(cx, rslt, _), ty);
     // Works because of a "convenient" bug that lets us
-    // return a mutable ivec as if it's immutable
+    // return a mutable vec as if it's immutable
     ret *rslt;
 }
 
diff --git a/src/comp/syntax/ext/simplext.rs b/src/comp/syntax/ext/simplext.rs
index 6386b628744..9b8a5e28e09 100644
--- a/src/comp/syntax/ext/simplext.rs
+++ b/src/comp/syntax/ext/simplext.rs
@@ -39,7 +39,7 @@ fn path_to_ident(pth: &path) -> option::t<ident> {
     ret none;
 }
 
-//an ivec of binders might be a little big.
+//a vec of binders might be a little big.
 type clause = {params: binders, body: @expr};
 
 /* logically, an arb_depth should contain only one kind of matchable */
diff --git a/src/comp/syntax/untyped_ast.rs b/src/comp/syntax/untyped_ast.rs
index 5534fbed57d..124a1e947f1 100644
--- a/src/comp/syntax/untyped_ast.rs
+++ b/src/comp/syntax/untyped_ast.rs
@@ -1,4 +1,4 @@
-import std::ivec;
+import std::vec;
 import std::vec::map;
 import std::option;
 import std::option::some;
@@ -410,7 +410,7 @@ fn cv_crate(ctx: &ctx, ut: &@ast_node) -> @crate {
 fn cv_crate_cfg(ctx: &ctx, ut: &@ast_node) -> crate_cfg {
     ret alt *ut {
       branch(n_crate_cfg., _, meta_items) {
-        ivec::map(bind cv_meta_item(ctx,_), meta_items)
+        vec::map(bind cv_meta_item(ctx,_), meta_items)
       }
       branch(_, sp, _) { ctx.ff(sp,"Invalid crate_cfg") }
     };
diff --git a/src/test/pretty/ivec-type.pp b/src/test/pretty/vec-type.pp
index e9c714af088..60265eebcf7 100644
--- a/src/test/pretty/ivec-type.pp
+++ b/src/test/pretty/vec-type.pp
@@ -1,4 +1,4 @@
-// pp-exact:ivec-type.pp
+// pp-exact:vec-type.pp
 
 fn f1(x: [int]) { }
 
diff --git a/src/test/pretty/ivec-type.rs b/src/test/pretty/vec-type.rs
index 717b50be9e3..010ad755f51 100644
--- a/src/test/pretty/ivec-type.rs
+++ b/src/test/pretty/vec-type.rs
@@ -1,4 +1,4 @@
-// pp-exact:ivec-type.pp
+// pp-exact:vec-type.pp
 
 fn f1(x: [int]) { }
diff --git a/src/test/compile-fail/bad-module.rs b/src/test/compile-fail/bad-module.rs
index 708db61bda4..bfb796916a3 100644
--- a/src/test/compile-fail/bad-module.rs
+++ b/src/test/compile-fail/bad-module.rs
@@ -1,4 +1,4 @@
-// error-pattern: unresolved import: ivec
-import ivec;
+// error-pattern: unresolved import: vec
+import vec;
 
 fn main() { let foo = vec::len([]); }
\ No newline at end of file